@@ -151,6 +151,12 @@ class GlobalEvent(Base):
         events = database.get_global_events()
         return [cls(event) for event in events]
 
+    @Base.lazy_load("_expire", use_default=False)
+    def expire(self):
+        if self._expire is None:
+            return None
+        return parse(self._expire)
+
 
 class SimulationData(Base):
     """
@@ -178,6 +184,10 @@ class SimulationData(Base):
     def next_season_start(self):
         return parse(self._next_season_start)
 
+    @Base.lazy_load("_season", use_default=False)
+    def season(self):
+        return self._season + 1
+
 
 class Player(Base):
     """
@@ -298,6 +308,8 @@ class Player(Base):
 
     @Base.lazy_load("_hitting_rating", use_default=False)
     def hitting_rating(self):
+        if getattr(self, "_hitting_rating", None):
+            return self._hitting_rating
         return (((1 - self.tragicness) ** 0.01) * ((1 - self.patheticism) ** 0.05) *
                 ((self.thwackability * self.divinity) ** 0.35) *
                 ((self.moxie * self.musclitude) ** 0.075) * (self.martyrdom ** 0.02))
@@ -306,16 +318,22 @@ class Player(Base):
 
     @Base.lazy_load("_pitching_rating", use_default=False)
     def pitching_rating(self):
+        if getattr(self, "_pitching_rating", None):
+            return self._pitching_rating
         return ((self.unthwackability ** 0.5) * (self.ruthlessness ** 0.4) *
                 (self.overpowerment ** 0.15) * (self.shakespearianism ** 0.1) * (self.coldness ** 0.025))
 
     @Base.lazy_load("_baserunning_rating", use_default=False)
     def baserunning_rating(self):
+        if getattr(self, "_baserunning_rating", None):
+            return self._baserunning_rating
         return ((self.laserlikeness**0.5) *
                 ((self.continuation * self.base_thirst * self.indulgence * self.ground_friction) ** 0.1))
 
     @Base.lazy_load("_defense_rating", use_default=False)
     def defense_rating(self):
+        if getattr(self, "_defense_rating", None):
+            return self._defense_rating
         return (((self.omniscience * self.tenaciousness) ** 0.2) *
                 ((self.watchfulness * self.anticapitalism * self.chasiness) ** 0.1))
 
@@ -998,6 +1016,27 @@ class Game(Base):
     def away_batter_mod(self):
         return Modification.load_one(getattr(self, "_away_batter_mod_id", None))
 
+    @staticmethod
+    def _payout_calc(odds, amount):
+        if odds == 0.5:
+            return round(2 * amount)
+        elif odds < 0.5:
+            return round(amount * (2 + 0.000555 * (100 * (0.5 - odds)) ** 2.4135))
+        else:
+            return round(amount * (2 - 0.000335 * (100 * (odds - 0.5)) ** 2.045))
+
+    def home_payout(self, bet):
+        """
+        Calculate the payout if the home team wins
+        """
+        return self._payout_calc(self.home_odds, bet)
+
+    def away_payout(self, bet):
+        """
+        Calculate the payout if the away team wins
+        """
+        return self._payout_calc(self.away_odds, bet)
+
 
 class Fight(Game):
     """Represents a Blaseball boss fight."""
@@ -1201,6 +1240,10 @@ class Playoff(Base):
     def winner(self):
         return Team.load(self._winner_id)
 
+    @Base.lazy_load("_season", use_default=False)
+    def season(self):
+        return self._season + 1
+
 
 class PlayoffRound(Base):
     """Represents a round of playoff games"""
